Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(492)

Unified Diff: net/http/transport_security_state_unittest.cc

Issue 2026213002: Refactor CertificateReportSender (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/transport_security_state.cc ('k') | net/net.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/transport_security_state_unittest.cc
diff --git a/net/http/transport_security_state_unittest.cc b/net/http/transport_security_state_unittest.cc
index 9f092d84a8462f27928f5630af1fd225c51681d9..8ce32ed2908a3a42d7e57c3142ce0448da193d78 100644
--- a/net/http/transport_security_state_unittest.cc
+++ b/net/http/transport_security_state_unittest.cc
@@ -78,10 +78,10 @@ const char* const kBadPath[] = {
nullptr,
};
// A mock ReportSender that just remembers the latest report
// URI and report to be sent.
class MockCertificateReportSender
- : public TransportSecurityState::ReportSender {
+ : public TransportSecurityState::ReportSenderInterface {
public:
MockCertificateReportSender() {}
~MockCertificateReportSender() override {}
@@ -107,16 +107,16 @@ class MockCertificateReportSender
std::string latest_report_;
};
// A mock ReportSender that simulates a net error on every report sent.
class MockFailingCertificateReportSender
- : public TransportSecurityState::ReportSender {
+ : public TransportSecurityState::ReportSenderInterface {
public:
MockFailingCertificateReportSender() : net_error_(ERR_CONNECTION_FAILED) {}
~MockFailingCertificateReportSender() override {}
int net_error() { return net_error_; }
- // TransportSecurityState::ReportSender:
+ // TransportSecurityState::ReportSenderInterface:
void Send(const GURL& report_uri, const std::string& report) override {
ASSERT_FALSE(error_callback_.is_null());
error_callback_.Run(report_uri, net_error_);
@@ -78,10 +78,10 @@ const char* const kBadPath[] = {
nullptr,
};
-// A mock ReportSender that just remembers the latest report
+// A mock ReportSenderInterface that just remembers the latest report
// URI and report to be sent.
class MockCertificateReportSender
@@ -107,16 +107,16 @@ class MockCertificateReportSender
std::string latest_report_;
};
-// A mock ReportSender that simulates a net error on every report sent.
+// A mock ReportSenderInterface that simulates a net error on every report sent.
class MockFailingCertificateReportSender
« no previous file with comments | « net/http/transport_security_state.cc ('k') | net/net.gypi » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698